@@ -1,7 +1,7 @@
 
-from src.providers.eth.provider import EthProvider
-from src.providers.provider import ProviderInterface
-from src.models.blockchains import Blockchains
+from multichain_explorer.src.providers.eth.eth_provider import EthProvider
+from multichain_explorer.src.providers.provider import ProviderInterface
+from multichain_explorer.src.models.blockchains import Blockchains
 
 class BlockchainProvider():
 
